/*
  Quentin Carbonneaux <qcarbonneaux@gmail.com>
  GPG Keyserver: pgp.mit.edu
  Key: C4D31021

  bignums, x86 optimized library dealing with
  arbitrary big positive numbers.

 */

#define _BSD_SOURCE
#include <stdlib.h>
#include <stdio.h>
#include <assert.h>
#include <sys/types.h>
#include <inttypes.h>
#include <primes.h>

#ifdef ARCH64
#define SZ_CAST uint64_t
#define W_SIZE 64
#define UINT uint64_t
#else
#define SZ_CAST uint32_t
#define W_SIZE 32
#define UINT uint32_t
#endif

/* #define B_EUCLIDE_GCD */ /* Uncomment this if you want to use       */
                            /* the classical Euclide algorithm         */
                            /* for gcd computations.                   */
                            /* XXX don't do that, b_egcd is not coded! */
#ifndef xalloc
#define xalloc malloc
#endif

/* #pragma pack(push,1) */
struct b_int {
  uint32_t size;
  UINT *buffer;
  unsigned char neg;
};
/* #pragma pack(pop) */

struct b_mgm_ctx {
  struct b_int r;
  struct b_int r2;
  UINT n;
  uint32_t p;
};

extern UINT b_overflow;

struct b_int b_alloc (uint32_t);
void b_free (struct b_int);
void b_zero (struct b_int);
void b_copy (struct b_int, struct b_int);
void b_zcopy(struct b_int, struct b_int);
void b_swap (struct b_int a, struct b_int b);
void b_add (struct b_int, struct b_int, struct b_int);
void b_mult (struct b_int, struct b_int, struct b_int);
void b_multw (struct b_int, UINT, struct b_int);
int b_gt (struct b_int, struct b_int);
int b_geqt (struct b_int, struct b_int);
void b_sub (struct b_int, struct b_int, struct b_int);
void b_shl (struct b_int, struct b_int, int32_t);
void b_shr (struct b_int, struct b_int, int32_t);
void b_shrw (struct b_int, struct b_int);
void b_mod (struct b_int, struct b_int, struct b_int);
void b_gcd (struct b_int, struct b_int, struct b_int);
void b_sprint (char *, struct b_int);
